/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Defines the interface for the AIPrompt outputs rendered in the **Output** view.
 */
export interface PromptOutput {
    /**
     * Represents the unique identifier of the prompt output.
     */
    id: number | string;
    /**
     * Represents the text content of the prompt output.
     */
    output: string;
    /**
     * Represents the prompt that initiates the output generation.
     */
    prompt: string;
    /**
     * Specifies an optional custom title for the prompt section.
     */
    title?: string;
    /**
     * Specifies if the prompt generation is initiated with the **Retry** button.
     */
    isRetry?: boolean;
    /**
     * (Optional) Specifies a command id, if the prompt generation is triggered via a command.
     */
    commandId?: string | number;
    /**
     * (Optional) Specifies the rating for the prompt output.
     */
    rating?: PromptOutputRating;
}
/**
 * Represents the rating of the prompt output.
 */
export type PromptOutputRating = "positive" | "negative";
