/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { ViewType } from '../models/view-type';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare abstract class BaseView {
    viewType: ViewType;
    private localization;
    hostClasses: boolean;
    /**
     * @hidden
     */
    template: TemplateRef<any>;
    constructor(viewType: ViewType, localization: LocalizationService);
    /**
     * Sets the text for the Toolbar button of the current view.
     */
    set buttonText(value: string);
    get buttonText(): string;
    /**
     * Sets the font icon for the Toolbar button of the current view.
     */
    set icon(value: string);
    get icon(): string;
    /**
     * Sets the SVG icon for the Toolbar button of the current view.
     */
    set svgIcon(value: SVGIcon);
    get svgIcon(): SVGIcon;
    /**
     * @hidden
     */
    messageFor(text: string): string;
    private _buttonText;
    private _icon;
    private _svgIcon;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseView, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaseView, never, never, { "buttonText": { "alias": "buttonText"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "svgIcon": { "alias": "svgIcon"; "required": false; }; }, {}, never, never, false, never>;
}
