/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Specifies the button type of a quick action ([see example](slug:suggested_actions_chat)).
 * * `openUrl`&mdash;Opens a new browser window with the specified URL.
 * * `reply`&mdash;Sends the action value as a reply in the Chat.
 * * `call`&mdash;Treats the value as a phone number. Similar to clicking a [telephone link](https://css-tricks.com/the-current-state-of-telephone-links/).
 * * other&mdash;Handled by user code in the [`executeAction`](slug:api_conversational-ui_chatcomponent#executeaction) event.
 */
export type ActionType = 'openUrl' | 'reply' | 'call' | string;
/**
 * Defines a quick action for a message.
 * The value is interpreted according to the specified `ActionType`.
 */
export interface Action {
    /**
     * Sets a predefined or custom type for the action.
     */
    type: ActionType;
    /**
     * Sets the value associated with the action.
     */
    value: any;
    /**
     * Sets the title for the quick action. If not set, the Chat displays the value.
     */
    title?: string;
}
