/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Represents a message attachment ([see example](slug:attachments_chat)).
 */
export interface Attachment {
    /**
     * Sets the content type identifier for the attachment. Typically a MIME type or any string.
     */
    contentType: string;
    /**
     * Sets the content of the attachment.
     */
    content: any;
    /**
     * Sets the title of the attachment.
     */
    title?: string;
    /**
     * Sets the subtitle of the attachment.
     */
    subtitle?: string;
}
/**
 * Specifies the layout for the message attachments ([see examples](slug:attachments_chat#display-modes)).
 *
 * The supported values are:
 * * `list`&mdash;A vertical list.
 * * `carousel`&mdash;A horizontal, scrollable list. Also called a card deck.
 */
export type AttachmentLayout = 'list' | 'carousel';
