/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter } from '@angular/core';
import { Action } from '../api/action.interface';
import * as i0 from "@angular/core";
/**
 * Represents a Hero Card component ([see example](slug:dialogflow_chat)).
 * Hero cards host a single large image and action buttons with text content.
 *
 * @example
 * ```html
 * <kendo-chat-hero-card
 *   title="Card Title"
 *   subtitle="Card Subtitle"
 *   [actions]="actions">
 * </kendo-chat-hero-card>
 * ```
 */
export declare class HeroCardComponent {
    /**
     * Sets the URL of the hero card image.
     */
    imageUrl: string;
    /**
     * Sets the title of the hero card.
     */
    title: string;
    /**
     * Sets the subtitle of the hero card.
     */
    subtitle: string;
    /**
     * Sets the array of quick actions for this hero card.
     */
    actions: Action[];
    cssClass: boolean;
    /**
     * Fires when the user clicks a button.
     */
    executeAction: EventEmitter<Action>;
    /**
     * Emits the `executeAction` event when the user clicks an action button.
     */
    onClick(action: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<HeroCardComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HeroCardComponent, "kendo-chat-hero-card", never, { "imageUrl": { "alias": "imageUrl"; "required": false; }; "title": { "alias": "title"; "required": false; }; "subtitle": { "alias": "subtitle"; "required": false; }; "actions": { "alias": "actions"; "required": false; }; }, { "executeAction": "executeAction"; }, never, never, true, never>;
}
