/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AfterViewInit, ElementRef, EventEmitter, OnDestroy, OnInit, QueryList, Renderer2 } from '@angular/core';
import { Action, ExecuteActionEvent, Message, User } from './api';
import { IntlService } from '@progress/kendo-angular-intl';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { ChatItem } from './chat-item';
import { ViewItem } from './chat-view';
import { AttachmentTemplateDirective } from './attachment-template.directive';
import { MessageTemplateDirective } from './message-template.directive';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class MessageListComponent implements OnInit, AfterViewInit, OnDestroy {
    private element;
    private intl;
    private renderer;
    set messages(value: Message[]);
    get messages(): Message[];
    attachmentTemplate: AttachmentTemplateDirective;
    messageTemplate: MessageTemplateDirective;
    localization: LocalizationService;
    user: User;
    executeAction: EventEmitter<ExecuteActionEvent>;
    navigate: EventEmitter<any>;
    resize: EventEmitter<any>;
    items: QueryList<ChatItem>;
    cssClass: boolean;
    view: ViewItem[] | any[];
    private _messages;
    private subs;
    private selectedItem;
    private keyActions;
    constructor(element: ElementRef, intl: IntlService, renderer: Renderer2);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    onResize(): void;
    formatTimeStamp(date: any): string;
    onKeydown(e: any): void;
    onBlur(args: any): void;
    isOwnMessage(msg: Message): boolean;
    dispatchAction(action: Action, message: Message): void;
    trackGroup(_index: number, item: ViewItem): any;
    select(item: ChatItem): void;
    last(items: any): any;
    private onHomeOrEndKeyDown;
    private onTabKeyDown;
    private navigateTo;
    /**
     * @hidden
     */
    textFor(key: string): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<MessageListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MessageListComponent, "kendo-chat-message-list", never, { "messages": { "alias": "messages"; "required": false; }; "attachmentTemplate": { "alias": "attachmentTemplate"; "required": false; }; "messageTemplate": { "alias": "messageTemplate"; "required": false; }; "localization": { "alias": "localization"; "required": false; }; "user": { "alias": "user"; "required": false; }; }, { "executeAction": "executeAction"; "navigate": "navigate"; "resize": "resize"; }, never, never, true, never>;
}
