/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Component, forwardRef, Input, TemplateRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { BaseView } from './base-view';
import * as i0 from "@angular/core";
import * as i1 from "@progress/kendo-angular-l10n";
/**
 * Represents the component that renders a **Custom** view in the AIPrompt.
 *
 * @example
 * ```html
 * <kendo-aiprompt-custom-view [viewTemplate]="customTemplate">
 * </kendo-aiprompt-custom-view>
 *
 * <ng-template #customTemplate>
 *   <div>Custom content here</div>
 * </ng-template>
 * ```
 */
export class CustomViewComponent extends BaseView {
    constructor(localization) {
        super('custom', localization);
    }
    /**
     * Sets the content of the Custom view as a template reference.
     */
    viewTemplate;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomViewComponent, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CustomViewComponent, isStandalone: true, selector: "kendo-aiprompt-custom-view", inputs: { viewTemplate: "viewTemplate" }, providers: [{
                provide: BaseView,
                useExisting: forwardRef(() => CustomViewComponent)
            }], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomViewComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-aiprompt-custom-view',
                    providers: [{
                            provide: BaseView,
                            useExisting: forwardRef(() => CustomViewComponent)
                        }],
                    template: ``,
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; }, propDecorators: { viewTemplate: [{
                type: Input
            }] } });
