/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from "./preventable-event";
/**
 * Represents the arguments for the `executeAction` event.
 *
 * The `executeAction` event fires when the user clicks a quick action button.
 * Call `preventDefault()` to suppress the built-in action handler.
 */
export class ExecuteActionEvent extends PreventableEvent {
    /**
     * Represents the action to execute.
     */
    action;
    /**
     * Represents the message that contains the action.
     */
    message;
    /**
     * @hidden
     */
    constructor(action, message) {
        super();
        this.action = action;
        this.message = message;
    }
}
