/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive, Optional, TemplateRef } from "@angular/core";
import * as i0 from "@angular/core";
/**
 * Defines a template for displaying message attachments.
 *
 * To define an attachment template, nest an `<ng-template>` tag with the `kendoChatAttachmentTemplate` attribute inside the `<kendo-chat>` component.
 * The template context is set to the attachment instance.
 * For more information, refer to the article on [message attachments](slug:attachments_chat).
 *
 * @example
 * ```html
 * <kendo-chat>
 *   <ng-template kendoChatAttachmentTemplate let-attachment>
 *     <div>Attachment: {{ attachment.content }}</div>
 *   </ng-template>
 * </kendo-chat>
 * ```
 */
export class AttachmentTemplateDirective {
    templateRef;
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AttachmentTemplateDirective, deps: [{ token: i0.TemplateRef, optional: true }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: AttachmentTemplateDirective, isStandalone: true, selector: "[kendoChatAttachmentTemplate]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AttachmentTemplateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoChatAttachmentTemplate]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef, decorators: [{
                    type: Optional
                }] }]; } });
