/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive, Optional, TemplateRef } from "@angular/core";
import * as i0 from "@angular/core";
/**
 * Defines a template for displaying Chat messages.
 *
 * To define a message template, nest an `<ng-template>` tag with the `kendoChatMessageTemplate` directive inside the `<kendo-chat>` component.
 * The template context is set to the `message` instance.
 * For more information, refer to the article on [message templates](slug:message_templates_chat).
 *
 * @example
 * ```html
 * <kendo-chat>
 *   <ng-template kendoChatMessageTemplate let-message>
 *     <div>Message: {{ message.text }}</div>
 *   </ng-template>
 * </kendo-chat>
 * ```
 */
export class MessageTemplateDirective {
    templateRef;
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessageTemplateDirective, deps: [{ token: i0.TemplateRef, optional: true }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: MessageTemplateDirective, isStandalone: true, selector: "[kendoChatMessageTemplate]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessageTemplateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoChatMessageTemplate]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef, decorators: [{
                    type: Optional
                }] }]; } });
