/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { KENDO_CONVERSATIONALUI } from './directives';
import { IconsService } from '@progress/kendo-angular-icons';
import { PopupService } from '@progress/kendo-angular-popup';
import { ResizeBatchService } from '@progress/kendo-angular-common';
import { DialogContainerService, DialogService, WindowContainerService, WindowService } from '@progress/kendo-angular-dialog';
import * as i0 from "@angular/core";
import * as i1 from "./ai-prompt/aiprompt.component";
import * as i2 from "./ai-prompt/views/prompt-view.component";
import * as i3 from "./ai-prompt/views/output-view.component";
import * as i4 from "./ai-prompt/views/command-view.component";
import * as i5 from "./ai-prompt/views/custom-view.component";
import * as i6 from "./ai-prompt/localization/custom-messages.component";
import * as i7 from "./ai-prompt/templates/toolbar-actions.template";
import * as i8 from "./ai-prompt/common/toolbar-focusable.directive";
import * as i9 from "./chat/chat.component";
import * as i10 from "./chat/l10n/custom-messages.component";
import * as i11 from "./chat/attachment-template.directive";
import * as i12 from "./chat/message-template.directive";
import * as i13 from "./chat/cards/hero-card.component";
import * as i14 from "./chat/message-box.directive";
// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [`NgModule`](link:site.data.urls.angular['ngmodules']) for the Conversational UI components.
 *
 * @example
 * ```ts
 * import { NgModule } from '@angular/core';
 * import { BrowserModule } from '@angular/platform-browser';
 * import { ConversationalUIModule } from '@progress/kendo-angular-conversational-ui';
 * import { AppComponent } from './app.component';
 *
 * @NgModule({
 *   declarations: [AppComponent],
 *   imports: [BrowserModule, ConversationalUIModule],
 *   bootstrap: [AppComponent]
 * })
 * export class AppModule {}
 * ```
 */
export class ConversationalUIModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ConversationalUIModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: ConversationalUIModule, imports: [i1.AIPromptComponent, i2.PromptViewComponent, i3.OutputViewComponent, i4.CommandViewComponent, i5.CustomViewComponent, i6.AIPromptCustomMessagesComponent, i7.AIPromptToolbarActionsDirective, i8.AIPromptToolbarFocusableDirective, i9.ChatComponent, i10.CustomMessagesComponent, i11.AttachmentTemplateDirective, i12.MessageTemplateDirective, i13.HeroCardComponent, i14.ChatMessageBoxTemplateDirective], exports: [i1.AIPromptComponent, i2.PromptViewComponent, i3.OutputViewComponent, i4.CommandViewComponent, i5.CustomViewComponent, i6.AIPromptCustomMessagesComponent, i7.AIPromptToolbarActionsDirective, i8.AIPromptToolbarFocusableDirective, i9.ChatComponent, i10.CustomMessagesComponent, i11.AttachmentTemplateDirective, i12.MessageTemplateDirective, i13.HeroCardComponent, i14.ChatMessageBoxTemplateDirective] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ConversationalUIModule, providers: [IconsService, PopupService, ResizeBatchService, DialogContainerService, DialogService, WindowService, WindowContainerService], imports: [i1.AIPromptComponent, i2.PromptViewComponent, i3.OutputViewComponent, i4.CommandViewComponent, i9.ChatComponent, i13.HeroCardComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ConversationalUIModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_CONVERSATIONALUI],
                    imports: [...KENDO_CONVERSATIONALUI],
                    providers: [IconsService, PopupService, ResizeBatchService, DialogContainerService, DialogService, WindowService, WindowContainerService]
                }]
        }] });
