/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AIPromptComponent } from "./ai-prompt/aiprompt.component";
import { CommandViewComponent } from "./ai-prompt/views/command-view.component";
import { AIPromptCustomMessagesComponent } from "./ai-prompt/localization/custom-messages.component";
import { CustomViewComponent } from './ai-prompt/views/custom-view.component';
import { AIPromptToolbarActionsDirective } from './ai-prompt/templates/toolbar-actions.template';
import { AIPromptToolbarFocusableDirective } from './ai-prompt/common/toolbar-focusable.directive';
import { OutputViewComponent, PromptViewComponent } from "./ai-prompt/views";
import { ChatComponent } from "./chat/chat.component";
import { CustomMessagesComponent } from "./chat/l10n/custom-messages.component";
import { AttachmentTemplateDirective } from "./chat/attachment-template.directive";
import { MessageTemplateDirective } from "./chat/message-template.directive";
import { HeroCardComponent } from "./chat/cards/hero-card.component";
import { ChatMessageBoxTemplateDirective } from "./chat/message-box.directive";
/**
 * Utility array that contains all AIPrompt related components and directives.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { KENDO_AIPROMPT } from '@progress/kendo-angular-conversational-ui';
 *
 * @Component({
 *   standalone: true,
 *   imports: [KENDO_AIPROMPT],
 *   selector: 'my-app',
 *   template: `<kendo-aiprompt></kendo-aiprompt>`
 * })
 * export class AppComponent {}
 * ```
 */
export const KENDO_AIPROMPT = [
    AIPromptComponent,
    PromptViewComponent,
    OutputViewComponent,
    CommandViewComponent,
    CustomViewComponent,
    AIPromptCustomMessagesComponent,
    AIPromptToolbarActionsDirective,
    AIPromptToolbarFocusableDirective
];
/**
 * Utility array that contains all Chat related components and directives.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { KENDO_CHAT } from '@progress/kendo-angular-conversational-ui';
 *
 * @Component({
 *   standalone: true,
 *   imports: [KENDO_CHAT],
 *   selector: 'my-app',
 *   template: `<kendo-chat></kendo-chat>`
 * })
 * export class AppComponent {}
 * ```
 */
export const KENDO_CHAT = [
    ChatComponent,
    CustomMessagesComponent,
    AttachmentTemplateDirective,
    MessageTemplateDirective,
    HeroCardComponent,
    ChatMessageBoxTemplateDirective
];
/**
 * Utility array that contains all `@progress/kendo-angular-conversational-ui` related components and directives.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { KENDO_CONVERSATIONALUI } from '@progress/kendo-angular-conversational-ui';
 *
 * @Component({
 *   standalone: true,
 *   imports: [KENDO_CONVERSATIONALUI],
 *   selector: 'my-app',
 *   template: `
 *     <kendo-aiprompt></kendo-aiprompt>
 *     <kendo-chat></kendo-chat>
 *   `
 * })
 * export class AppComponent {}
 * ```
 */
export const KENDO_CONVERSATIONALUI = [
    ...KENDO_AIPROMPT,
    ...KENDO_CHAT
];
